@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2003, 2004, 2005, 2007 Free Software Foundation
+ * Copyright (C) 2003, 2004, 2005, 2007, 2008 Free Software Foundation
  *
  * Author: Nikos Mavrogiannopoulos
  *
@@ -28,11 +28,9 @@
 #include <gnutls_int.h>
 #include <gnutls_errors.h>
 #include <gnutls_global.h>
-#include <mpi.h>
 #include <libtasn1.h>
 #include <common.h>
-#include <x509.h>
-#include <extensions.h>
+#include <x509_int.h>
 #include <gnutls_datum.h>
 
 /* This function will attempt to return the requested extension found in
@@ -66,7 +64,7 @@ _gnutls_x509_crt_get_extension (gnutls_x509_crt_t cert,
     {
       k++;
 
-      snprintf( name, sizeof(name), "tbsCertificate.extensions.?%u", k);
+      snprintf (name, sizeof (name), "tbsCertificate.extensions.?%u", k);
 
       len = sizeof (str) - 1;
       result = asn1_read_value (cert->cert, name, str, &len);
@@ -190,7 +188,7 @@ _gnutls_x509_crt_get_extension_oid (gnutls_x509_crt_t cert,
     {
       k++;
 
-      snprintf( name, sizeof(name), "tbsCertificate.extensions.?%u", k);
+      snprintf (name, sizeof (name), "tbsCertificate.extensions.?%u", k);
 
       len = sizeof (str) - 1;
       result = asn1_read_value (cert->cert, name, str, &len);
@@ -328,7 +326,7 @@ overwrite_extension (ASN1_TYPE asn, unsigned int indx,
   const char *str;
   int result;
 
-  snprintf( name, sizeof(name), "tbsCertificate.extensions.?%u", indx);
+  snprintf (name, sizeof (name), "tbsCertificate.extensions.?%u", indx);
 
   if (critical == 0)
     str = "FALSE";
@@ -381,7 +379,7 @@ _gnutls_x509_crt_set_extension (gnutls_x509_crt_t cert,
     {
       k++;
 
-      snprintf( name, sizeof(name), "tbsCertificate.extensions.?%u", k);
+      snprintf (name, sizeof (name), "tbsCertificate.extensions.?%u", k);
 
       len = sizeof (extnID) - 1;
       result = asn1_read_value (cert->cert, name, extnID, &len);
@@ -525,7 +523,7 @@ _gnutls_x509_ext_extract_basicConstraints (int *CA,
 	*pathLenConstraint = -1;
       else if (result != GNUTLS_E_SUCCESS)
 	{
-	  gnutls_assert();
+	  gnutls_assert ();
 	  asn1_delete_structure (&ext);
 	  return _gnutls_asn2err (result);
 	}
@@ -953,9 +951,8 @@ int
 _gnutls_x509_ext_extract_proxyCertInfo (int *pathLenConstraint,
 					char **policyLanguage,
 					char **policy,
-					size_t *sizeof_policy,
-					opaque * extnValue,
-					int extnValueLen)
+					size_t * sizeof_policy,
+					opaque * extnValue, int extnValueLen)
 {
   ASN1_TYPE ext = ASN1_TYPE_EMPTY;
   int result;
